<?php

namespace Drupal\cookiepro_ccpa\Form;

use Drupal\Core\Form\ConfigFormBase;

use Drupal\Core\Form\FormStateInterface;

use Drupal\file\Entity\File;

use Drupal\Core\Render\Markup;

/**
 * {@inheritdoc}
 */
class MessagesForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'cookiepro_ccpa.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cookiepro_ccpa_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('cookiepro_ccpa.settings');
    $form['button_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('CCPA Settings'),
      '#open' => TRUE,
    ];
    $form['button_settings']['isLinkEnabled'] = [
      '#type' => 'radios',
      '#title' => $this->t('Opt-out Button'),
      '#options' => ['text_link' => $this->t('Text Link'), 'button' => $this->t('Button')],
      '#default_value' => $config->get('isLinkEnabled'),
      '#prefix' => '<div class="section_one allsections">',
    ];

    $form['button_settings']['link_text'] = [
      '#type' => 'textfield',
      '#title' => '',
      '#value' => '<a id="otCCPAdoNotSellLink" href="javascript:void(0);" data-ot-ccpa-opt-out="link" style="display:none;">Do Not Sell My Personal Information</a>',
      '#description' => 'Copy and paste the above snippet onto your website.',
      '#attributes' => ['readonly' => 'readonly'],
      '#prefix'       => '<div class="copybuttontext">',
    ];

    $form['button_settings']['copy_button'] = [
      '#type' => 'button',
      '#title' => '',
      '#value' => 'Copy',
      '#suffix' => '</div>',
      '#attributes' => [
        'onclick' => 'return false;',
      ],
    ];

    $form['button_settings']['button_text'] = [
      '#type' => 'textfield',
      '#title' => '',
      '#value' => '<button type="button" data-ot-ccpa-opt-out="button" style="display:none;" class="ot-ccpa-optout__button ot-ccpa-optout__button--light"><img src="https://cookie-cdn.cookiepro.com/ccpa-optout-solution/v1/assets/icon-do-not-sell.svg" style="width:30px;height:30px;" alt="" role="presentation"><span class="ot-ccpa-optout__button__title">Do Not Sell My Personal Information</span></button>',
      '#description' => 'Copy and paste the above snippet onto your website.',
      '#attributes' => ['readonly' => 'readonly'],
      '#prefix'       => '<div class="copybuttontext2">',
    ];
    $form['button_settings']['copy_button2'] = [
      '#type' => 'button',
      '#title' => '',
      '#value' => 'Copy',
      '#suffix' => '</div></div>',
      '#attributes' => [
        'onclick' => 'return false;',
      ],
    ];
    $form['button_settings']['isButtonEnabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Floating Button'),
      '#default_value' => $config->get('isButtonEnabled'),
      '#prefix' => '<div class="section_two allsections">',
    ];
    $form['button_settings']['Image_Icon'] = [
      '#type' => 'managed_file',
      '#title' => $this->t('Icon'),
      '#upload_location' => 'public://ccpamoduleicon',
      '#upload_validators' => [
        'file_validate_extensions' => ['png', 'jpeg', 'jpg'],
      ],
      '#default_value' => $config->get('Image_Icon'),
      '#theme' => 'image_widget',
      '#preview_image_style' => 'medium',
    ];

    $form['button_settings']['buttonBackgroundColor'] = [
      '#type' => 'color',
      '#title' => $this->t('Button Background'),
      '#default_value' => $config->get('buttonBackgroundColor'),
      '#prefix' => '</div><div class="section_three allsections">',
    ];
    $form['button_settings']['button_text_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Button Text'),
      '#default_value' => $config->get('button_text_color'),
    ];
    $form['button_settings']['header_icon_background'] = [
      '#type' => 'color',
      '#title' => $this->t('Header and Icon Background'),
      '#default_value' => $config->get('header_icon_background'),
    ];
    $form['button_settings']['header_text_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Header Text'),
      '#default_value' => $config->get('header_text_color'),
    ];
    $form['button_settings']['button_position'] = [
      '#type' => 'radios',
      '#title' => $this->t('Button Position'),
      '#options' => ['left' => $this->t('Left'), 'right' => $this->t('Right')],
      '#default_value' => $config->get('button_position'),
      '#suffix' => '</div>',
    ];

    $form['button_settings']['popup_main_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#default_value' => $config->get('popup_main_title'),
      '#prefix' => '<div class="section_four allsections">',
    ];
    $form['button_settings']['PrivacyPolicyMessage'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Message'),
      '#default_value' => $config->get('PrivacyPolicyMessage'),
    ];
    $form['button_settings']['privacy_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Policy Label'),
      '#default_value' => $config->get('privacy_text'),
    ];
    $form['button_settings']['privacy_link'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Policy URL'),
      '#default_value' => $config->get('privacy_link'),
      '#suffix' => '</div>',
    ];
    $form['button_settings']['selectuseroption'] = [
      '#type' => 'radios',
      '#title' => $this->t('Select User Access'),
      '#options' => [
        'all' => $this->t('Show to all users'),
        'US' => $this->t('Show only to users from the US'),
        'California' => $this->t('Show only to users from california'),
      ],
      '#default_value' => $config->get('selectuseroption'),
      '#prefix' => '<div class="section_five allsections">',
      '#suffix' => '</div>',
    ];
    $form['button_settings']['isEmailEnabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display Email Address?'),
      '#description' => $this->t('If a site visitor clicks the Do Not Sell Button, they will be provided with the email address entered below that they can contact if further action is needed to complete the consumer rights request. <a href="https://www.cookiepro.com/data-subject-rights/" target="_blank">Learn More</a>'),
      '#default_value' => $config->get('isEmailEnabled'),
      '#prefix' => '<div class="section_six allsections">',
    ];
    $form['button_settings']['emailAddress'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Email Address'),
      '#default_value' => $config->get('emailAddress'),
      '#suffix' => '</div>',
    ];
    $form['button_settings']['isPhoneEnabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display Phone Number?'),
      '#description' => $this->t('If a site visitor clicks the Do Not Sell Button, they will be provided with the phone number entered below that they can contact if further action is needed to complete the consumer rights request. <a href="https://www.cookiepro.com/data-subject-rights/" target="_blank">Learn More</a>'),
      '#default_value' => $config->get('isPhoneEnabled'),
      '#prefix' => '<div class="section_seven allsections">',
    ];
    $form['button_settings']['phoneNumber'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Phone Number'),
      '#default_value' => $config->get('phoneNumber'),
      '#suffix' => '</div>',
    ];

    $form['button_settings']['form_enable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Consumer Rights Request Form'),
      '#description' => $this->t('Display link to Consumer Rights Request form. Sign up to get access to your own Data Subject Request portal for free. <a href="https://www.cookiepro.com/data-subject-rights/" target="_blank">Learn More</a>'),
      '#default_value' => $config->get('form_enable'),
      '#prefix' => '<div class="section_eight allsections">',
    ];
    $form['button_settings']['form_link_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link Label'),
      '#default_value' => $config->get('form_link_text'),
    ];
    $form['button_settings']['form_link_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Form URL'),
      '#default_value' => $config->get('form_link_url'),
      '#suffix' => '</div>',
    ];

    $form['button_settings']['isGooglePersonalizeEnabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Opt-out of Ad Partners'),
      '#description' => $this->t('Disable Google and its technology partners from collecting data and using cookies for advertisements personalization and measurement.'),
      '#default_value' => $config->get('isGooglePersonalizeEnabled'),
      '#prefix' => '<div class="section_nine allsections">',
    ];
    $form['button_settings']['isIABEnabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Utilize the IAB CCPA framework to Opt-out of Sale'),
      '#default_value' => $config->get('isIABEnabled'),
      '#prefix' => '<div class="personalizegroup">',
    ];
    $form['button_settings']['isLSPAenable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('My business has signed the IAB Limited Service Provider Agreement.'),
      '#default_value' => $config->get('isLSPAenable'),
    ];
    $form['button_settings']['googleConfirmationTitle'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Toggle Label'),
      '#default_value' => $config->get('googleConfirmationTitle'),
    ];
    $form['button_settings']['googleConfirmationMessage'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Message'),
      '#default_value' => $config->get('googleConfirmationMessage'),
    ];
    $form['button_settings']['confirmbutton'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Confirm Label'),
      '#default_value' => $config->get('confirmbutton'),
      '#suffix' => $this->previewhtml(),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $form_file = $form_state->getValue('Image_Icon', 0);
    if (isset($form_file[0]) && !empty($form_file[0])) {
      $file = File::load($form_file[0]);
      $file->setPermanent();
      $file->save();
    }
    $this->config('cookiepro_ccpa.settings')
      ->set('isLinkEnabled', $form_state->getValue('isLinkEnabled'))
      ->set('isButtonEnabled', $form_state->getValue('isButtonEnabled'))
      ->set('buttonBackgroundColor', $form_state->getValue('buttonBackgroundColor'))
      ->set('button_text_color', $form_state->getValue('button_text_color'))
      ->set('header_icon_background', $form_state->getValue('header_icon_background'))
      ->set('header_text_color', $form_state->getValue('header_text_color'))
      ->set('button_position', $form_state->getValue('button_position'))

      ->set('popup_main_title', $form_state->getValue('popup_main_title'))
      ->set('PrivacyPolicyMessage', $form_state->getValue('PrivacyPolicyMessage'))
      ->set('privacy_text', $form_state->getValue('privacy_text'))
      ->set('privacy_link', $form_state->getValue('privacy_link'))
      ->set('selectuseroption', $form_state->getValue('selectuseroption'))
      ->set('isEmailEnabled', $form_state->getValue('isEmailEnabled'))
      ->set('emailAddress', $form_state->getValue('emailAddress'))

      ->set('Image_Icon', $form_state->getValue('Image_Icon'))
      ->set('isPhoneEnabled', $form_state->getValue('isPhoneEnabled'))
      ->set('phoneNumber', $form_state->getValue('phoneNumber'))
      ->set('isLSPAenable', $form_state->getValue('isLSPAenable'))
      ->set('form_enable', $form_state->getValue('form_enable'))
      ->set('form_link_text', $form_state->getValue('form_link_text'))
      ->set('form_link_url', $form_state->getValue('form_link_url'))
      ->set('isGooglePersonalizeEnabled', $form_state->getValue('isGooglePersonalizeEnabled'))
      ->set('isIABEnabled', $form_state->getValue('isIABEnabled'))
      ->set('googleConfirmationTitle', $form_state->getValue('googleConfirmationTitle'))
      ->set('googleConfirmationMessage', $form_state->getValue('googleConfirmationMessage'))
      ->set('confirmbutton', $form_state->getValue('confirmbutton'))
      ->save();
  }

  /**
   * Creating the preview html.
   */
  public function previewhtml() {
    $ccpa_settings = \Drupal::config('cookiepro_ccpa.settings')->get();
    global $base_url;
    $position_class = '';
    if ('left' === $ccpa_settings['button_position']) {
      $position_class = 'leftaligncontent';
    }

    if (!empty($ccpa_settings['Image_Icon'])) {
      $drupal_file_uri = File::load($ccpa_settings['Image_Icon'][0])->getFileUri();
      $image_path = file_create_url($drupal_file_uri);
    }
    else {
      global $base_url;
      $image_path = $base_url . '/' . drupal_get_path('module', 'cookiepro_ccpa') . '/images/icon.png';
    }

    $html = '
	</div></div></div>
	<div class="preview_section">
		<div class="preview_head">
			<span class="settings-text">Preview</span>
			<span class="shortdescription">Save changes to update preview</span>
		</div>
		<div class="form-control-group ot-preview-body">';
    if (1 === $ccpa_settings['isButtonEnabled']) {
      $html .= '<span class="previewheading">Floating Button</span>
			<div class="ot-preview-background ot-preview-screen">
				<div class="ot-banner-button ' . $position_class . '" style="background-color: ' . $ccpa_settings['header_icon_background'] . ';">
					<img src="' . $image_path . '" alt="CookiePro Do Not Sell" title="CookiePro Do Not Sell">
				</div>
			</div>';
    }
    $html .= '
			<span class="previewheading">Inline Button</span>
			<div class="ot-preview-background ot-preview-screen">
				<div class="ot-banner-button-two">';
    if ('button' === $ccpa_settings['isLinkEnabled']) {
      $html .= '			<div type="button" style="display:inline-block;" class="ot-ccpa-optout__button ot-ccpa-optout__button--light">
						<img src="https://cookie-cdn.cookiepro.com/ccpa-optout-solution/v1/assets/icon-do-not-sell.svg" style="width:30px;height:30px;" alt="" role="presentation"><span class="ot-ccpa-optout__button__title">Do Not Sell My Personal Information</span>
						<span class="ot-ccpa-optout__button__subtitle"><img style="display:block!important;opacity:1!important;height:25px!important;width:152px!important;" src="https://cookie-cdn.cookiepro.com/ccpa-optout-solution/v1/assets/poweredbycookiepro.svg" title="Powered by CookiePro" alt="Powered by CookiePro"></span>
					</div>';
    }
    else {
      $html .= '<a id="otCCPAdoNotSellLink" href="javascript:void(0);" data-ot-ccpa-opt-out="button">Do Not Sell My Personal Information</a>';
    }
    $html .= '					
				</div>
			</div>
		</div>	
		<span class="previewheading">Modal</span>
		<div class="ot-preview-background popupbutton popupcloseicon ' . $position_class . '">
			<div class="ot-banner-confirmation-popup">
				<div class="side-popup-column-main" style="background-color: ' . $ccpa_settings['header_icon_background'] . ';color: ' . $ccpa_settings['header_text_color'] . '">
					<p class="popup-title-main">' . $ccpa_settings['popup_main_title'] . '</p>
					<p class="ot-confirmation-popup-text">' . $ccpa_settings['PrivacyPolicyMessage'];
    if (!empty($ccpa_settings['privacy_link'])) {
      $html .= '
						<a href="' . $ccpa_settings['privacy_link'] . '" target="_blank" style="color: ' . $ccpa_settings['header_text_color'] . '">' . $ccpa_settings['privacy_text'] . '</a>';
    }
    $html .= '	</p>
					<p class="ot-confirmation-popup-text">';
    if (1 === $ccpa_settings['isEmailEnabled'] && !empty($ccpa_settings['emailAddress'])) {
      $html .= '		<span class="email-address-icon">
							<a href="mailto:' . $ccpa_settings['emailAddress'] . '" style="color: ' . $ccpa_settings['header_text_color'] . '">' . $ccpa_settings['emailAddress'] . '</a>
							<br />
						</span>';
    }
    if (1 === $ccpa_settings['isPhoneEnabled'] && !empty($ccpa_settings['phoneNumber'])) {
      $html .= '		<span class="phone-number-icon">
							<a href="tel:' . $ccpa_settings['phoneNumber'] . '" style="color: ' . $ccpa_settings['header_text_color'] . '">' . $ccpa_settings['phoneNumber'] . '</a>
						</span> <br />';
    }
    if (1 === $ccpa_settings['form_enable'] && !empty($ccpa_settings['form_link_url'])) {
      $html .= '		<span class="form-link-icon">
							<a href="' . $ccpa_settings['form_link_url'] . '" target="_blank" style="color: ' . $ccpa_settings['header_text_color'] . '">' . $ccpa_settings['form_link_text'] . '</a>
						</span>';
    }
    $html .= '	</p>
				</div>
				<div class="personal-info">
					<div class="ot-confirmation-popup-header">
						<p class="personal-info-title">' . $ccpa_settings['googleConfirmationTitle'] . '</p>
						<label class="ot-toggle-switch googleConfirmation">
							<input type="checkbox" name="ConfirmationEnabled" id="ConfirmationEnabled" checked="">
							<span class="ot-toggle-slider sliderinfo round"></span>
						</label>
						<div class="clearboth"></div>						
					</div>
					<p class="ot-confirmation-popup-text">' . $ccpa_settings['googleConfirmationMessage'] . '</p>					
				</div>	
																			
				<div class="popup-footer">	
					<div class="powered-by-icon">
						<img src="' . $base_url . '/' . drupal_get_path('module', 'cookiepro_ccpa') . '/images/PoweredByCookiePro.svg" alt="CookiePro" title="CookiePro">
					</div>
					<div class="ot-banner-button ConfirmBtn" style="background-color:' . $ccpa_settings['buttonBackgroundColor'] . ';">
						<input type="button" value="' . $ccpa_settings['confirmbutton'] . '" style="color: ' . $ccpa_settings['button_text_color'] . ';">
					</div>
					<div class="clearboth"></div>
				</div>
			</div>		
			<div class="confirmation-popup-close" style="background-color: ' . $ccpa_settings['header_icon_background'] . ';">
				<img src="' . $base_url . '/' . drupal_get_path('module', 'cookiepro_ccpa') . '/images/Close.svg" alt="Close Icon" title="Close Icon">
			</div>
		</div>

		</div>
	';

    return Markup::create($html);
  }

}
